// sensors.p
//
// This program is run in the Sensors Virtual Machine, the part of Pleo that continuously
// monitors the 39 physical sensors on the robot.  The on_sensor() function below is
// automatically called each time one of the real or virtual sensors on the Pleo is
// triggered by some outside event.
//
// A 'switch' control structure looks at the name of sensor that triggered the event.
// Add a 'case' selector for each sensor you want to set a sound or motion for.
 
#pragma pack 1 // this saves space by packing all strings - we do this at the start of every script.

#include <Log.inc>
#include <Script.inc>
#include <Sensor.inc>
#include <Sound.inc>
#include <Motion.inc>

#include "sounds.inc"
#include "motions.inc"

public on_sensor(time, sensor_name: sensor, value)
{
	switch (sensor)
    {
	
	    // Capacitive touch sensors
	
		case SENSOR_HEAD:
		{
			sound_play(snd_ar_ur);
		}

		case SENSOR_CHIN:
		{
			sound_play(snd_awh);
		}

		case SENSOR_BACK:
		{
			motion_play(mot_nap_getup);
		}
		
		case SENSOR_LEFT_LEG:
		{
			sound_play(snd_bite);
		}
		
		case SENSOR_RIGHT_LEG:
		{
			sound_play(snd_breath_01);
		}
		
		case SENSOR_LEFT_ARM:
		{
			sound_play(snd_breath_02);
		}
		
		case SENSOR_RIGHT_ARM:
		{
			sound_play(snd_eat_01);
		}
		
		case SENSOR_TAIL:
		{
			motion_play(mot_nap);
		}
		  
		  
		// Bottom-of-foot tactile sensors
		
		case SENSOR_FRONT_LEFT:
		{
			sound_play(snd_ar_ur);
		}

		case SENSOR_FRONT_RIGHT:
		{
			sound_play(snd_ar_ur);
		}

		case SENSOR_BACK_LEFT:
		{
			sound_play(snd_ar_ur);
		}

		case SENSOR_BACK_RIGHT:
		{
			sound_play(snd_ar_ur);
		}

		
		case SENSOR_OBJECT: // an object is in front of Pleo's nose IR sensors
		{
			sound_play(snd_sniff_01);
		}

		case SENSOR_MOUTH:
		{
			sound_play(snd_chew);
		}
		  	  
		default:
		{
			// If no case above matches we can execute a set of default statements here.
		}
	}
	
    return true; // when we're done we return 'true' to reset the sensor that triggered us.
}